@@ -5,7 +5,10 @@ import logging
 import inspect
 import traceback
 from tauk.enums import TestStatusType
-from tauk.utils import TestResult, format_appium_log, format_error, get_testcase_steps, flatten_desired_capabilities, get_automation_type, calculate_elapsed_time_ms, get_platform_name, get_platform_version
+from tauk.utils import (TestResult, format_appium_log, format_error, get_testcase_steps,
+                        flatten_desired_capabilities, get_automation_type, calculate_elapsed_time_ms,
+                        get_platform_name, get_platform_version, print_modified_exception_traceback
+                        )
 import requests
 from requests.exceptions import HTTPError, ConnectionError, Timeout, RequestException
 
@@ -108,8 +111,14 @@ class Tauk:
     @classmethod
     def observe(cls, func):
 
-        caller_frame = inspect.stack()[1]
-        caller_filename = ntpath.basename(caller_frame.filename)
+        all_frames = inspect.stack()
+        caller_frame = None
+        caller_filename = None
+        for frame_info in all_frames:
+            if func.__name__ in frame_info.frame.f_code.co_names:
+                caller_frame = frame_info
+                caller_filename = caller_frame.filename
+                break
 
         def invoke_test_case(*args, **kwargs):
             try:
@@ -119,8 +128,12 @@ class Tauk:
                 failure_end_time = time.perf_counter()
 
                 exc_type, exc_value, exc_traceback = sys.exc_info()
-                traceback_info = traceback.extract_tb(exc_traceback)
-                filename, line_number, invoked_func, code_executed = traceback_info[-1]
+                stack_summary_list = traceback.extract_tb(exc_traceback)
+                filename, line_number, invoked_func, code_executed = None, None, None, None
+                for stack_trace in stack_summary_list:
+                    if stack_trace.filename == caller_filename:
+                        filename, line_number, invoked_func, code_executed = stack_trace
+                        break
 
                 testcase_steps = get_testcase_steps(
                     testcase=func,
@@ -130,7 +143,7 @@ class Tauk:
                 test_result = TestResult(
                     test_status=TestStatusType.excluded.name if cls._excluded else TestStatusType.failed.name,
                     test_name=func.__name__,
-                    filename=caller_filename,
+                    filename=ntpath.basename(caller_filename),
                     desired_caps=cls._get_desired_capabilities(),
                     appium_log=cls._get_log(),
                     page_source=cls._get_page_source(),
@@ -147,8 +160,13 @@ class Tauk:
                 )
                 test_result.screenshot = cls._get_screenshot()
                 cls._test_results.append(test_result)
-                # traceback.print_exception(exc_type, exc_value, exc_traceback, limit=-1)
-                # raise exc_type(exc_value).with_traceback(exc_traceback.tb_next)
+
+                # Suppress the traceback information
+                # (only the exception type and value will be printed)
+                # and print our custom traceback information
+                print_modified_exception_traceback(
+                    exc_type, exc_value, exc_traceback, tauk_package_filename=__file__)
+                sys.tracebacklimit = 0
                 raise
             else:
                 success_end_time = time.perf_counter()
@@ -211,19 +229,27 @@ class Tauk:
                 except HTTPError as http_status_error:
                     logging.error("An HTTP status code error occurred.")
                     logging.error(http_status_error)
-                    logging.error(response.text)
+                    logging.error(http_status_error.response.text)
+                    try:
+                        print(
+                            f"ERROR: {http_status_error.response.json().get('error')}")
+                    except:
+                        print(f"ERROR: {http_status_error.response.text}")
                 except ConnectionError as connection_error:
                     logging.error("An error connecting to the API occurred.")
                     logging.error(connection_error)
-                    logging.error(response.text)
+                    logging.error(connection_error.text)
+                    print("ERROR: Unable to connect to the Tauk Platform.")
                 except Timeout as timeout_error:
                     logging.error("A timeout error occurred.")
                     logging.error(timeout_error)
-                    logging.error(response.text)
+                    logging.error(timeout_error.text)
+                    print("ERROR: The upload request timed out.")
                 except RequestException as request_error:
                     logging.error(
                         "An error occurred trying to make an upload request.")
                     logging.error(request_error)
-                    logging.error(response.text)
+                    logging.error(request_error.text)
+                    print(f"ERROR: Unable to perform an upload request.")
                 else:
                     return response.json()
